import { NextRequest } from "next/server";
import { authenticateUser } from "@/utils/auth";
import Page from "@/models/Page";
import connectToDatabase from "@/utils/mongoose";
import { logError } from "@/utils/logger";
import { createResponse } from "@/utils/apiResponse";

export async function GET(request: NextRequest) {
  try {
    await connectToDatabase();

    const url = new URL(request.url);
    const title = url.pathname.split("/").pop();

    console.log("Full URL:", request.url);
    console.log("Extracted Title:", title);

    if (!title) {
      return createResponse(null, "Title is required", "Bad Request", 400);
    }

    const page = await Page.findOne({ title }).lean();

    if (!page) {
      return createResponse(null, `Page with title ${title} not found`, "Not Found", 404);
    }

    if (!Array.isArray(page) && page.status !== "published") {
      const auth = await authenticateUser(request);
      if (!auth.authorized) return auth.response;
    }

    return createResponse(page, "Page retrieved successfully");
  } catch (error) {
    logError(error as Error, "GET /api/pages/[title]");
    return createResponse(null, "Internal Server Error", "Server Error", 500);
  }
}

