"use client";

import { useSession } from "next-auth/react";
import { useEffect, useState } from "react";

import UserList from "./UserList";
import PageList from "./PageList";
import FileList from "./FileList";
import FileUpload from "@/components/common/FileUpload";
// import { usePopup } from "@/components/modula/PopupProvider";

import { PanelLeft, History, Bell, Sun } from "lucide-react";
import SideBar from "./SideBar";

declare module "next-auth" {
  interface Session {
    user: {
      id: string;
      name?: string | null;
      email?: string | null;
      image?: string | null;
      role?: string;
    };
  }
}

export default function Dashboard() {
  const { data: session, status } = useSession();
  // const { showPopup } = usePopup();
  const [activeSection, setActiveSection] = useState<string>("users");
  const [isClient, setIsClient] = useState(false);

  useEffect(() => {
    setIsClient(true);
  }, []);

  if (!isClient) return null;

  if (status === "loading") return <p>Loading...</p>;

  if (!session) {
    return (
      <div>
        <h1>Access Denied</h1>
        <p>You need to be authenticated to access this page.</p>
      </div>
    );
  }

  if (session && session.user.role === "visitor") {
    return (
      <div>
        <h1>Access Denied</h1>
        <p>You need to be an admin to access this page.</p>
      </div>
    );
  }

  return (
    <main className="h-screen px-4 py-5 space-x-10 flex flex-row bg-background">

      <SideBar setActiveSection={setActiveSection} activeSection={activeSection} />

      <section className="w-full bg-foreground shadow-md rounded-lg overflow-scroll relative">
        <div className="bg-white flex items-center justify-between p-4 sticky top-0 border-b-2 border-primary z-10">
          <div className="flex items-center space-x-4">
            <PanelLeft />
            <span className="text-gray-500">Dashboards</span>
            <span className="text-gray-300">/</span>
            <span className="text-black capitalize">{activeSection}</span>
          </div>
          <div className="flex items-center space-x-4">
            <input type="text" placeholder="Search" className="bg-black/5 text-gray-500 rounded-full pl-4 pr-4 py-1 focus:outline-none" />
            <Sun />
            <History />
            <Bell />
          </div>
        </div>

        {activeSection === "users" && <UserList />}
        {activeSection === "pages" && <PageList />}
        {activeSection === "media" && <FileList />}
        {activeSection === "fileupload" && <FileUpload />}
      </section>
    </main>
  );
}
