import React from 'react';
import { Component, ContainerComponent, DropItem } from "@/types/componentTypes";
import NestedDropZone from "./NestedDropZone";
import { componentMap, widthClasses } from "@/utils/componentUtils";
import { Trash2, FileSlidersIcon } from "lucide-react";

interface ComponentRendererProps {
  components: Component[];
  handleDropInside: (parentId: number, item: DropItem) => void;
  deleteComponent: (id: string) => void;
  setEditingComponent: (component: Component) => void;
  setShowEditor: (show: boolean) => void;
}

const ComponentRenderer: React.FC<ComponentRendererProps> = ({
  components,
  handleDropInside,
  deleteComponent,
  setEditingComponent,
  setShowEditor,
}) => {
  const isContainerComponent = (component: Component): component is ContainerComponent => {
    return 'children' in component;
  };

  return (
    <>
      {components.map((comp) => {
        const ComponentToRender = componentMap[comp.type];
        if (!ComponentToRender) {
          return null;
        }
        const parentIsRow = parent && (parent as unknown as ContainerComponent).type === "row";
        const siblingCount = parentIsRow ? (parent as unknown as ContainerComponent).children.length : 1;
        const dynamicWidth = parentIsRow ? widthClasses[siblingCount as keyof typeof widthClasses] || "w-full" : "w-full";

        const canHaveChildren = ["section", "row", "column", "parallaxSeparator"].includes(comp.type);

        return (
          <div
            key={comp.id}
            className={`w-full md:${dynamicWidth} p-2 border border-dashed border-gray-400 rounded relative`}
          >
            <div className="flex flex-col justify-between items-center">
              <div className="w-full flex flex-row justify-between mb-1">
                <p className="text-gray-700">{comp.type}</p>
                <div className="w-auto flex">
                  <button
                    onClick={() => { setEditingComponent(comp); setShowEditor(true); }}
                    className="ml-2 text-blue-500 text-xs flex items-center"
                  >
                    <FileSlidersIcon size={20} />
                  </button>
                  <button
                    onClick={() => deleteComponent(comp.id)}
                    className="ml-2 text-red-500 text-xs flex items-center"
                  >
                    <Trash2 size={20} />
                  </button>
                </div>
              </div>

              {canHaveChildren && (
                <NestedDropZone parentId={parseInt(comp.id)} onDrop={handleDropInside}>
                  <ComponentToRender title={''} width={''} text={''} src={''} alt={''} url={''} embedId={''} image={''} imageHero={''} {...comp.props}>
                    {isContainerComponent(comp) && <ComponentRenderer
                      components={comp.children}
                      handleDropInside={handleDropInside}
                      deleteComponent={deleteComponent}
                      setEditingComponent={setEditingComponent}
                      setShowEditor={setShowEditor}
                    />}
                  </ComponentToRender>
                </NestedDropZone>
              )}

              {!canHaveChildren &&
                <ComponentToRender
                  imageHero={''} title={''} width={''} text={''} src={''} alt={''} url={''} embedId={''} image={''} {...comp.props}>
                  {null}
                </ComponentToRender>}
            </div>
          </div>
        );
      })}
    </>
  );
};

export default ComponentRenderer;