'use client';
import React from 'react'
import { useParams } from 'next/navigation';

import Canva from './Canva'
import Toolbar from './Toolbar'
import { Component } from '@/types/componentTypes';

const componentNames: Record<string, string> = {
	hero: 'Hero',
	section: 'Section',
	row: 'Row',
	column: 'Column',
	titleBlock: 'Title Block',
	textBlock: 'Text Block',
	imageBlock: 'Image',
	button: 'Button',
	video: 'Video',
	parallaxSeparator: 'Parallax Separator',
};

const componentsList: Component[] = [
	{ id: crypto.randomUUID(), type: 'hero', props: { imageHero: "/uploads/placeholder.webp", title: "Title here" } },
	{ id: crypto.randomUUID(), type: 'section', props: { className: '' }, children: [] },
	{ id: crypto.randomUUID(), type: 'row', props: { className: '' }, children: [] },
	{ id: crypto.randomUUID(), type: 'column', props: { width: 'w-full', className: '' }, children: [] },
	{ id: crypto.randomUUID(), type: 'titleBlock', props: { text: 'Title Example', level: 1, className: '' } },
	{ id: crypto.randomUUID(), type: 'textBlock', props: { text: "<strong>Lorem Ipsum</strong> is simply dummy text of the printing and typesetting industry.", className: ''} },
	{ id: crypto.randomUUID(), type: 'imageBlock', props: { src: '/uploads/placeholder.webp', alt: 'Imagen de ejemplo', className: '' } },
	{ id: crypto.randomUUID(), type: 'button', props: { text: 'Haz clic', url: '/', bgColor: '', textColor: '', className: '' } },
	{ id: crypto.randomUUID(), type: 'video', props: { embedId: '7Eqgfst6y10' } },
	{
		id: crypto.randomUUID(),
		type: 'parallaxSeparator',
		props: {
			image: '/placeholder-parallax.jpg',
			overlayColor: 'rgba(0, 0, 0, 0.5)',
			height: '400px',
		},
		children: [],
	},	
];



const DragNDrop = () => {
	const { title } = useParams();
	
	return (
		<div className='flex flex-row h-screen'>
			<Toolbar componentsList={componentsList} componentNames={componentNames} />
			<Canva pageEdit={decodeURIComponent((title ?? '').toString())}></Canva>
		</div>
	)
}

export default DragNDrop;
