/**
 * NestedDropZone Component: Handles drop functionality within child components.
 */
'use client';

import React from 'react';
import { useDrop } from 'react-dnd';
import { DropItem } from '@/types/componentTypes';

const NestedDropZone: React.FC<{
  parentId: number;
  onDrop: (parentId: number, item: DropItem) => void;
  children: React.ReactNode;
}> = ({ parentId, onDrop, children }) => {
  const [{ isOver }, drop] = useDrop({
    accept: 'component',
    drop: (item: DropItem, monitor) => {
      if (monitor.didDrop()) return;
      onDrop(parentId, item);
    },
    collect: (monitor) => ({
      isOver: monitor.isOver({ shallow: true }),
    }),
  });

  return (
    <div
      ref={drop as unknown as React.Ref<HTMLDivElement>}
      className={`w-full p-2 border rounded ${
        isOver ? 'border-blue-500 bg-blue-50' : 'border-dashed border-gray-400'
      }`}
    >
      {children}
    </div>
  );
};

export default NestedDropZone;

