import React from 'react';
import { useDrag } from 'react-dnd';
import { Component } from '@/types/componentTypes';

interface ToolbarProps {
    componentsList: Component[];
    componentNames: Record<string, string>;
}

function Toolbar({ componentsList, componentNames }: ToolbarProps) {
    return (
        <div className="w-64 bg-gray-100 border-r-2 border-gray-300 p-4 space-y-4 overflow-scroll">
            <h2 className="font-bold text-lg mb-4">Components</h2>
            <div className="flex flex-col space-y-2">
                {componentsList.map((component, index) => (
                    <DraggableComponent key={index} component={component} name={componentNames[component.type]} />
                ))}
            </div>
        </div>
    );
}

interface DraggableComponentProps {
    component: Component;
    name: string;
}

function DraggableComponent({ component, name }: DraggableComponentProps) {
    const [{ isDragging }, drag] = useDrag(() => ({
        type: 'component',
        item: { ...component },
        collect: (monitor) => ({
            isDragging: !!monitor.isDragging(),
        }),
    }));

    return (
        <div
            ref={drag as unknown as React.Ref<HTMLDivElement>}
            className={`p-3 rounded-lg shadow-md bg-white hover:bg-gray-200 border ${isDragging ? "opacity-50 border-blue-400" : "border-gray-300"
                } cursor-pointer transition-all`}
        >
            <p className="font-medium text-gray-700">{name}</p>
            <p className="text-sm text-gray-500">{component.type}</p>
        </div>
    );
}

export default Toolbar;
