'use client';

import React from "react";
import Link from "next/link"; // Usa el Link de Next.js

interface ButtonProps {
  text: string; // Texto del botón
  url: string; // URL o ruta interna
  bgColor?: string; // Color de fondo del botón
  textColor?: string; // Color del texto del botón
  className?: string; // Clases adicionales opcionales
}

export const Button: React.FC<ButtonProps> = ({
  text,
  url,
  bgColor = "bg-primary",
  textColor = "text-white",
  className = "",
}) => {
  // Detecta si es una URL externa
  const isExternal = /^https?:\/\//.test(url);

  return (
    <div className="w-auto">
      {isExternal ? (
        // Si es URL externa, usa <a>
        <a
          href={url}
          target="_blank" // Abre en una nueva pestaña
          rel="noopener noreferrer" // Seguridad adicional
          className={`inline-block ${bgColor} ${textColor} text-xl px-4 py-2 rounded hover:brightness-125 hover:scale-110 transition-opacity ${className}`}
        >
          {text}
        </a>
      ) : (
        // Si es ruta interna, usa <Link> de Next.js
        <Link
          href={url}
          className={`inline-block ${bgColor} ${textColor} text-xl px-4 py-2 rounded hover:brightness-125 hover:scale-110 transition-opacity ${className}`}
        >
          {text}
        </Link>
      )}
    </div>
  );
};

export default Button;