import React, { useState } from "react";
import { Link } from "react-router-dom";
import { ChevronDown, Menu, X } from "lucide-react";

type NavItem = {
  title: string;
  path: string;
  items?: NavItem[];
};

const navItems: NavItem[] = [
  {
    title: "Home",
    path: "/",
  },
  {
    title: "About Us",
    path: "/about-us",
  },
  {
    title: "The Holy Rosary",
    path: "/holy-rosary",
  },
  {
    title: "Our Rosary Makers",
    path: "/our-rosary-makers",
  },
  {
    title: "News",
    path: "/news",
    items: [
      {
        title: "Latest News",
        path: "/news/latest",
      },
      {
        title: "Archives",
        path: "/news/archives",
      },
    ],
  },
];

function Navbar() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);

  return (
    <nav className="">
      <div className="container mx-auto px-4">
        <div className="flex justify-between items-center py-4">
          {/* Hamburger Menu Button */}
          <button
            className="lg:hidden text-primary"
            onClick={() => setIsMenuOpen(!isMenuOpen)}
          >
            {isMenuOpen ? <X size={24} /> : <Menu size={24} />}
          </button>

          {/* Navigation Items */}
          <div
            className={`${
              isMenuOpen ? "block" : "hidden"
            } lg:flex flex-col lg:flex-row lg:items-center lg:space-x-6 absolute lg:static top-full left-0 w-full lg:w-auto bg-white lg:bg-transparent shadow-lg lg:shadow-none px-10 py-4`}
          >
            {navItems.map((item, index) => (
              <div key={index} className="relative group my-2 md:my-0">
                <Link
                  to={item.path}
                  className="flex items-center space-x-1 text-primary font-bold hover:text-primary/80 transition-colors w-full md:w-auto"
                >
                  <span>{item.title}</span>
                  {item.items && item.items.length > 0 && (
                    <ChevronDown
                      size={16}
                      className="group-hover:rotate-180 transition-transform duration-200"
                    />
                  )}
                </Link>

                {/* Dropdown Menu */}
                {item.items && item.items.length > 0 && (
                  <div className="absolute z-50 hidden group-hover:block bg-white shadow-lg mt-2 min-w-[200px] rounded-md overflow-hidden transform opacity-0 group-hover:opacity-100 transition-all duration-200 -translate-y-2 group-hover:translate-y-0">
                    <div className="bg-primary w-full h-1"></div>
                    {item.items.map((subItem, subIndex) => (
                      <Link
                        key={subIndex}
                        to={subItem.path}
                        className="block px-4 py-2 text-primary font-bold hover:bg-blue-50 transition-colors"
                      >
                        {subItem.title}
                      </Link>
                    ))}
                  </div>
                )}
              </div>
            ))}
          </div>
        </div>
      </div>
    </nav>
  );
}

export default Navbar;
