import mongoose, { Schema, Document } from 'mongoose';

export interface IUser extends Document {
  name: string;
  email: string;
  password?: string;
  provider: 'credentials' | 'github' | 'google';
  role: 'admin' | 'editor' | 'autor' | 'colaborator' | 'visitor';
  createdAt: Date;
}

const UserSchema = new Schema<IUser>({
  name: { type: String, required: true, unique: true },
  email: { type: String, required: true, unique: true },
  password: { type: String, select: false },
  provider: { type: String, enum: ['credentials', 'github', 'google'], required: true },
  role: { type: String, enum: ['admin', 'editor', 'autor', 'colaborator', 'visitor'], default: 'visitor', required: true },
  createdAt: { type: Date, default: Date.now },
});

const User = mongoose.models.User || mongoose.model<IUser>('User', UserSchema);
export default User;
