import { getToken } from "next-auth/jwt";
import { NextResponse } from "next/server";
import { NextRequest } from "next/server";
import { ApiResponse } from "@/types";

import connectToDatabase from "./mongoose";
import User from "@/models/User";

// Helper function for standardized responses
function createResponse<T>(
  data?: T,
  message?: string,
  error?: string,
  status: number = 200
): NextResponse {
  const response: ApiResponse<T> = {
    success: !error,
    ...(data && { data }),
    ...(message && { message }),
    ...(error && { error }),
  };
  return NextResponse.json(response, { status });
}

// ✅ Secure helper function to enforce authentication
export async function authenticateUser(req: NextRequest) {
  const token = await getToken({ req, secret: process.env.NEXTAUTH_SECRET });

  if (!token) {
    return { authorized: false, response: createResponse(undefined, undefined, "Unauthorized", 401) };
  }

  await connectToDatabase();

  const user = await User.findById(token.id);

  if (!user) {
    return { authorized: false, response: createResponse(undefined, undefined, "User not found", 404) };
  }

  return { authorized: true, user: { token: token, id: token.id, role: token.role, name: token.name } };
}