import fs from "fs";
import path from "path";

/**
 * Standardized error logging function
 * Logs errors to `error.log` file and console.
 */
export function logError(error: Error, source?: string) {
  const timestamp = new Date().toISOString();
  const logMessage = `
  [ERROR] ${timestamp}
  Source: ${source || "Unknown"}
  Message: ${error.message}
  Stack Trace: ${error.stack || "No stack available"}
  ----------------------------------------
  `;

  // Log to console
  console.error(logMessage);

  // Write to `error.log` file
  const logFilePath = path.join(process.cwd(), "error.log");
  fs.appendFileSync(logFilePath, logMessage);
}
