export interface ApiResponse<T = unknown> {
  success: boolean;
  data?: T;
  message?: string;
  error?: string;
}

export async function unpublishPage(pageId: string): Promise<ApiResponse<null>> {
  try {
    const response = await fetch(`/api/pages/`, {
      method: "PUT",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify({ id: pageId, status: "draft" }),
    });

    const data: ApiResponse<null> = await response.json();

    if (!response.ok) {
      throw new Error(data.error || "Failed to update page status");
    }

    return { success: true, message: "Page status updated to Draft ✅" };
  } catch (error) {
    console.error("Error publishing page:", error);
    return { success: false, error: (error as Error).message || "Unknown error" };
  }
}
